@@ -20,7 +20,6 @@ from pytconf.param import Param, NO_DEFAULT
 from pytconf.utils import get_logger
 
 PARAMS_ATTRIBUTE = "_params"
-DEFAULT_GROUP_NAME: str = "default"
 SPECIAL_COMMANDS = {"help", "help-suggest", "help-all"}
 
 
@@ -97,21 +96,27 @@ class PytconfConf:
         self._configs = set()
         self._config_names = set()
         self.main_function = None
+        self.main_description = None
         self.function_name_to_configs: Dict[str, List[Type[Config]]] = dict()
         self.function_name_to_suggest_configs: Dict[str, List[Type[Config]]] = dict()
         self.function_name_to_callable: Dict[str, Callable] = dict()
-        self.function_group_names: Dict[str, Set[str]] = defaultdict(set)
+        self.function_group_names: Dict[Union[str, None], Set[str]] = defaultdict(set)
         self.allow_free_args: Dict[str, bool] = dict()
         self.min_free_args: Dict[str, Union[int, None]] = dict()
         self.max_free_args: Dict[str, Union[int, None]] = dict()
+        self.description: Dict[str, Union[str, None]] = dict()
         self.function_group_descriptions: Dict[str, str] = dict()
-        self.function_group_list = []
+        self.function_group_list: List[Union[str, None]] = [None]
         self.attribute_to_config: Dict[str, Type[Config]] = dict()
         self.free_args: List[str] = []
         self.app_name: Union[str, None] = None
 
-    def register_main(self, f):
-        self.main_function = f
+    def register_main(self,
+                      main_function: Callable,
+                      main_description: Union[str, None] = None,
+                      ):
+        self.main_function = main_function
+        self.main_description = main_description
 
     def register_config(self, config: Type[Config], name):
         """
@@ -135,44 +140,56 @@ class PytconfConf:
         for error in errors.errors:
             print_error(error)
 
-    def show_help(self) -> None:
-        print("Usage: {} [OPTIONS] COMMAND [ARGS]...".format(self.app_name))
+    def get_main_description(self):
+        if self.main_description is not None:
+            return self.main_description
         doc = get_first_line(self.main_function.__doc__)
         if doc is not None:
-            print()
-            doc = "\n".join(map(lambda x: "  {}".format(x.strip()), doc.split("\n")))
-            print_highlight("{}".format(doc))
-        print()
-        print("Options:")
+            return doc
+        # doc = "\n".join(map(lambda x: "  {}".format(x.strip()), doc.split("\n")))
+        return None
+
+    def show_help(self) -> None:
+        print("Usage: {} [OPTIONS] COMMAND [ARGS]...".format(self.app_name))
+        main_doc = self.get_main_description()
+        if main_doc is not None:
+            print_highlight(f"\n  {main_doc}")
+        print("\nOptions:")
         print("  --help         Show mandatory help")
         print("  --help-suggest Show mandatory+suggestions help")
         print("  --help-all     Show all help")
-        print()
-        print("Commands:")
+        print("\nCommands:")
+        single_group = len(self.function_group_list) == 1
         for function_group in self.function_group_list:
-            description = self.function_group_descriptions[function_group]
-            print("  {}: {}".format(function_group, description))
+            if not single_group:
+                description = self.function_group_descriptions[function_group]
+                print("  {}: {}".format(function_group, description))
             for name in sorted(self.function_group_names[function_group]):
-                f = self.function_name_to_callable[name]
-                doc = get_first_line(f.__doc__)
-                if doc is None:
-                    print_highlight("    {}".format(name))
+                function_doc = self.get_function_description(name)
+                if function_doc is None:
+                    print_highlight(f"    {name}")
                 else:
-                    print("    {}: {}".format(color_hi(name), doc))
+                    print(f"    {color_hi(name)}: {function_doc}")
             print()
 
+    def get_function_description(self, name: str):
+        description = self.description[name]
+        if description is not None:
+            return description
+        f = self.function_name_to_callable[name]
+        doc = get_first_line(f.__doc__)
+        if doc is not None:
+            return doc
+        return None
+
     def show_help_for_function(
         self, function_name: str, show_help_full: bool, show_help_suggest: bool
     ) -> None:
-        print("Usage: {} {} [OPTIONS] [ARGS]...".format(self.app_name, function_name,))
-        function_selected = self.function_name_to_callable[function_name]
-        doc = get_first_line(function_selected.__doc__)
-        if doc is not None:
-            print()
-            print_highlight("  {}".format(doc))
-        print()
-        print("Options:")
-        print()
+        print(f"Usage: {self.app_name} {function_name} [OPTIONS] [ARGS]...")
+        function_doc = self.get_function_description(function_name)
+        if function_doc is not None:
+            print_highlight(f"\n  {function_doc}")
+        print("\nOptions:\n")
         for config in self.function_name_to_configs[function_name]:
             self.show_help_for_config(config)
         if show_help_suggest:
@@ -203,7 +220,7 @@ class PytconfConf:
             )
             more_help = param.more_help()
             if more_help is not None:
-                print("      {}".format(more_help))
+                print(f"      {more_help}")
         print()
 
     def process_flags(
@@ -298,6 +315,18 @@ class PytconfConf:
         self.read_flags_from_config(file_name=self.get_system_config(), flags=flags)
         self.read_flags_from_config(file_name=self.get_user_config(), flags=flags)
 
+        # get the command (it's the first argument if it doesnt start with --
+        # if there are free args then the command is the first of these
+        # find the selected command
+        command_selected = None
+        if not args[0].startswith("--"):
+            command = args.pop(0)
+            if command in self.function_name_to_callable:
+                command_selected = command
+            else:
+                errors.add_error("unknown command [{}]".format(command))
+
+        # now parse the args
         self.parse_args(args, errors, flags, special_flags)
 
         # handle help flags
@@ -314,17 +343,6 @@ class PytconfConf:
             show_help = True
             show_help_full = True
 
-        # find the selected command
-        command_selected = None
-
-        # if there are free args then the command is the first of these
-        if len(self.free_args) >= 1:
-            command = self.free_args.pop(0)
-            if command in self.function_name_to_callable:
-                command_selected = command
-            else:
-                errors.add_error("unknown command [{}]".format(command))
-
         # if there are no free args and just one function then this is it
         if len(self.function_name_to_callable) == 1:
             command_selected = list(self.function_name_to_callable.keys())[0]
@@ -342,7 +360,7 @@ class PytconfConf:
                         errors.add_error("too many free args - {} required".format(max_args))
             else:
                 if len(self.free_args) > 0:
-                    errors.add_error("free args are not allowed")
+                    errors.add_error(f"free args are not allowed [{self.free_args}]")
 
         if command_selected is None:
             if not show_help:
@@ -395,21 +413,23 @@ class PytconfConf:
 
     def get_html(self) -> str:
         html_gen = HtmlGen()
-        doc = get_first_line(self.main_function.__doc__)
-        assert doc is not None
-        html_gen.line("h1", doc)
+        main_doc = self.get_main_description()
+        if main_doc is not None:
+            html_gen.line("h1", main_doc)
         html_gen.line("h2", "API specifications")
+        single_group = len(self.function_group_list) == 1
         with html_gen.tag("ul"):
             for function_group_name in self.function_group_list:
-                function_group_description = self.function_group_descriptions[
-                    function_group_name
-                ]
-                html_gen.line("li", function_group_name, title="function group name: ")
-                html_gen.line(
-                    "li",
-                    function_group_description,
-                    title="function group description: ",
-                )
+                if not single_group:
+                    function_group_description = self.function_group_descriptions[
+                        function_group_name
+                    ]
+                    html_gen.line("li", function_group_name, title="function group name: ")
+                    html_gen.line(
+                        "li",
+                        function_group_description,
+                        title="function group description: ",
+                    )
                 with html_gen.tag("li"):
                     for function_name in sorted(
                         self.function_group_names[function_group_name]
@@ -500,20 +520,24 @@ def register_function_group(
     pt.function_group_list.append(function_group_name)
 
 
-def register_main() -> Callable[[Any], Any]:
-    def identity(f):
-        get_pytconf().register_main(f)
-        return f
+def register_main(main_description: Union[str, None] = None) -> Callable[[Any], Any]:
+    def identity(main_function):
+        get_pytconf().register_main(
+            main_function=main_function,
+            main_description=main_description,
+        )
+        return main_function
     return identity
 
 
 def register_endpoint(
     configs: List[Type[Config]] = (),
     suggest_configs: List[Type[Config]] = (),
-    group: str = DEFAULT_GROUP_NAME,
+    group: Union[str, None] = None,
     allow_free_args: bool = False,
     min_free_args: Union[int, None] = None,
     max_free_args: Union[int, None] = None,
+    description: Union[str, None] = None,
 ) -> Callable[[Any], Any]:
     logger = get_logger()
     logger.debug("registering endpoint")
@@ -527,6 +551,7 @@ def register_endpoint(
             allow_free_args=allow_free_args,
             min_free_args=min_free_args,
             max_free_args=max_free_args,
+            description=description,
         )
         return f
 
@@ -537,10 +562,11 @@ def register_function(
     f: Callable,
     configs: List[Type[Config]] = (),
     suggest_configs: List[Type[Config]] = (),
-    group: str = DEFAULT_GROUP_NAME,
+    group: Union[str, None] = None,
     allow_free_args: bool = False,
     min_free_args: Union[int, None] = None,
     max_free_args: Union[int, None] = None,
+    description: Union[str, None] = None,
 ) -> None:
     function_name = f.__name__
     pt = get_pytconf()
@@ -551,6 +577,7 @@ def register_function(
     pt.allow_free_args[function_name] = allow_free_args
     pt.min_free_args[function_name] = min_free_args
     pt.max_free_args[function_name] = max_free_args
+    pt.description[function_name] = description
 
 
 def write_config_file_json_user():
